<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Ka jete edhe jashte Shfletuesit te Internetit
</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licencuar te: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 Eshte Program i Lire por Programuesit te tij i merr kohe te qmueshme</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Ju lutem &lt;a href=&quot;%1&quot;&gt; dhuroni&lt;/a&gt; qe te perkrahni vazhdimin e ndertimit te %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Perkthe %1 ne gjuhen e tuaj ame duke perdorur %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Dizajnimi i ikones u be nga %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Leshuar nen &lt;a href=&quot;%1&quot;&gt; GNU Licanca Publike Gjenerale&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation> Afer</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Afersisht</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Jepni detajet rreth licences</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Shifër:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Ju lutem licenconi %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Versioni demostrues ka perfunduar</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Pa licenc programmit do ti mbaron afati ne %1 ditë</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Duke bler versionin e plot , ju gjithashtu do te perkrahni punen e mundimshme qe kam ber per krijimin %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Perdorni verionin demostrues</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Jepni licencën</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Blini licencë</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Nga %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>T&apos;gjitha videot</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Videot e pa shikuara</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Emri</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Arrnimi i fundit</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Shtimi i dundit</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Shtimi i fundit</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Me e shikuara</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Rendit sipas</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Shëno të gjitha si të shikuara</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Shfaq arrnimin</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Nuk keni abonime . Perdor simbolin yll për tu abonuar te kanalet</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>T&apos;gjitha videot</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Videot e pa shikuara</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Nuk ka abonime të freskuar për momentin</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 e shikimeve</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>Bajts</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>Bajts/Sekond</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/Sekond</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/Sekond</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>Sekonda</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>Minuta</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 Mbetet</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 shkarkuar në %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Shkarkimi ka përfunduar</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Ndrysho lokacionin</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Zghidhni lokacionin e shkarkimeve</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Lokacioni i shkarkimeve u ndryshua.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Shkarkimet e tanishme ende do te ruhen ne lokacionin e meparshem te shkarkimeve.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Duke shkarkuar ne : %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Shkarkimet</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reinstall</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Luaje</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pushim</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Luaje/Pushim</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Ndaloje</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Ndaloje se luajturi pas kenges aktuale</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Kenga e ardhshme</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Kenga e meparshme</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Rrite zerin</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Ule zerin</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Pa ze</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Kerko perpara</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Kerko prapa</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Kerkim</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Gjeni videot dhe kanalet me fjalët kyqe</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Shfleto</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Shfleto videot sipas kategoris</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Abonimet</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Kanalet e abonuara</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Rehatoni veten</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Dritare</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp; Minimizoje</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>Ndaloje</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Ndaloje rishikimin dhe kthehu prapa te pamje e kerkimit</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>Mehershme</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Kthehu prapa te kenga e kaluar</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Kaperce</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Kaperce te video e ardhshme</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Luaj</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Rinis rishikimin</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Ekran te plote</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Kalo ne ekran te plot</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>Ne mod kompakte</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Fshih listen e videove dhe shiritin e veglave</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Hap faqen &amp; e Youtube </translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Kalo ne faqen e videove te YouTube dhe pushoje rishikimin</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Kopjo linkun nga YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopjoje linkun e videos se tanishme ne tabelen e ngjitjes</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Kopjo rrjedhen e videos &amp; URL</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopjoje URL e rrjedhes se videos aktuale  ne tabelen e ngjitjes</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Gjej videot &amp; Pjeset</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Gjeni pjes te tjera te videove ne rednin e duhur</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Largo</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Largoje videon e zgjedhur nga lista e luajtjes</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Leviz lart</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Levize lart videon e zgjedhur ne listen e luajtjes</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Leviz posht</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Levize posht videon e zghedhur ne listen e luajtjes</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>Pastro kerkimet e me parshme</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Pastro historin e kerkimeve . Nuk mund te zhbehet</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Lëre</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Mireupafshim</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Adrese interneti</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 ne Web</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Beni nje donacion</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Ju lutem perkrahni vazhdimin e ndertimit te %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Rreth</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informata rreth %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Kerkim</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Hesht zerin</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Fillo luajtjen manualisht</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Manualisht fillo luajtjen e videove</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>Shkarkimet</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Trego detajet rreth videove te shkarkuara</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>Shkarko</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Shkarko videon e tanishme</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp; Abonohu në Kanal</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Shperndaj videon aktuale duke perdorur %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>% Email</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation> Afer</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Nxjerr ne Krye</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Ndalo pas kesaj video</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>%Raportoni një problem...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>%Përpuno kërkimin....</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Më shum....</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Videot e afërme</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Shiko videot që jan të aferta me videon aktuale</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Blej %1....</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>Aplikacion</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Ridegjim</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Lista e luajtjes</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Shperndaje</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Shiko</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ndihma</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Shtyp %1 qe te rrisni zerin , shtyp %2 qe ta ulni zerin</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Zgjidhni përmbajtjen e mjedisit tuaj</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Duke hapur %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Deshironi te dilni %1 me nje shkarkim ne prapavij?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Nese e mbyllni %1 tani , ky shkarkim do te nderpritet.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Mbyll dhe ndalo shkarkimin</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Prisni per shkarkimin qe te mbaroj</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Gabim:%1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>Pushoje</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pushoje rishikimin</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Largohu &amp; Ekran te plote</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Koha e mbetur:%1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Zeri ne %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Zeri eshte heshtur</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Zeri eshte leshuar</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Maksimumi i definicionit te videos eshte vendosur ne %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Privatsia juaj tani eshte e sigurt</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Shkarkimet jan kompletuar</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 versioni %2 eshte i gatshem</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Me rikujto me von</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Arrnim</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Tani ju mund te ngjitni YouTube linqe ne nje tjeter program</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Tani ju mund te ngjitni rrdhjedhen e YouTube URL ne nje tjeter program</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Linku do te jet i vlefshem per nje kohe te kufizuar</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Duke shkarkuar %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>I</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>Pjas</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>Episode</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Derguar nga %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Q&apos;abonohu nga %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Abonohu në %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Një version i %1 është i gatshëm</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 është i gatshëm . Ju keni %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Dëshiron që ta shkarkoni tani?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Kalo këtë version</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Ma rikujtoni më vonë</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Instalo Përditësimet</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Ngjit</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 e %2 (%3)--%4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Duke pregaditur</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Dështoi</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Përfunduat</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Ndaluar</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Ndalo shkarkimin</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Shfaq në %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Hap dosjen e burimit</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Rifillo shkarkimin</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Shfaq %1 më shumë</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Nuk ka video</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nuk ka me video tjera</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Rendit sipas</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Përkatësi</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datë</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Shiko Llogarit</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Klafifikom</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Në qdo kohë</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Sot</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 dit</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 dit</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Kohëzgjatja</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Gjithë</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Shkurt</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mesatar</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>I gjatë</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Më pak se 4 minuta</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Mes 4 dhe 20 minutash</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Më gjat se 20 minuta</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kualiteti</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Definicion i lartë</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p ose më i lartë</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Kry</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Kry</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Kerkim</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Mire se erdhet ne &lt;h href=&quot;%1&quot;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>Per te filluar shikimin e videove.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>Nje fjal kyqe</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Hyr</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Fjalit kyqe te fundit</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Kanali i fundit</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Merrni versionin e plote</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>Prapa</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Përpara në %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Prapa në %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Rafino kërkimin</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Menduat:%1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Ndrysho lokacionin</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Me i përhapuri</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Duke shkarkuar përditësimet</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algjeria</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argjentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgjika</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brazil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Kanadë</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Kili</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Kolumbia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Republika Qeke</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egjipt</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Francë</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Gjermani</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Gana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Greqi</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Hungari</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Indi</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irland</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Izrael</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Itali</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japoni</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordani</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenia</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malejzia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Meksik</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Maroko</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Hollandë</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Zelanda e re</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeri</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipinet</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Poloni</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusi</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Arabia Saudite</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapor</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Afrika Jugore</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Korea Jugore</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Spanjë</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Suedi</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Tajvan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunisi</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turki</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Emirated e Bashkuara Arabe</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Mretëria e Bashkuar</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Jemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Mbar Bota</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Nuk mund te merr rrjedhen e videos per %1</translation>
    </message>
</context>
</TS>